@@ -153,11 +153,40 @@
 #endif
 
 #ifdef MRN_KEY_PART_SPEC_FIELD_NAME_USE_CONST_STRING
-  typedef LEX_CSTRING mrn_key_part_spec_field_name;
+#  if (MYSQL_VERSION_ID >= 80013 && !defined(MRN_MARIADB_P))
+     typedef char mrn_key_part_spec_field_name;
+#  else
+     typedef LEX_CSTRING mrn_key_part_spec_field_name;
+#  endif
 #else
   typedef LEX_STRING mrn_key_part_spec_field_name;
 #endif
 
+#if MYSQL_VERSION_ID >= 80013 && !defined(MRN_MARIADB_P)
+#  define MRN_KEY_PART_SPEC_FIELD_NAME_USE_ACCESSSOR_FUNCTION
+#  define MRN_KEY_PART_SPEC_FIELD_NAME(key_part_spec)			\
+     (key_part_spec)->get_field_name()
+#  define MRN_KEY_PART_SPEC_FIELD_NAME_FORMAT "%s"
+#  define MRN_KEY_PART_SPEC_FIELD_NAME_VALUE(key_part_spec)		\
+     (key_part_spec)
+#  define MRN_FIELD_NAME_EQUAL_KEY_PART_SPEC_FIELD_NAME(field, name)	\
+     (strcmp((field)->field_name, name) == 0)
+#else
+#  define MRN_KEY_PART_SPEC_FIELD_NAME(key_part_spec)			\
+     &(key_part_spec)->field_name
+#  define MRN_KEY_PART_SPEC_FIELD_NAME_FORMAT "%.*s"
+#  define MRN_KEY_PART_SPEC_FIELD_NAME_VALUE(key_part_spec)		\
+     static_cast<int>((key_part_spec)->length), (key_part_spec)->str
+#  ifdef MRN_FIELD_FIELD_NAME_IS_LEX_STRING
+#    define MRN_FIELD_NAME_EQUAL_KEY_PART_SPEC_FIELD_NAME(field, string)	\
+       FIELD_NAME_EQUAL_STRING(field, string)
+#  else
+#    define MRN_FIELD_NAME_EQUAL_KEY_PART_SPEC_FIELD_NAME(field, string)	\
+       (strlen((field)->field_name) == string->length &&			\
+        strncmp((field)->field_name, string->str, string->length) == 0)
+#  endif
+#endif
+
 #if MYSQL_VERSION_ID >= 100302 && defined(MRN_MARIADB_P)
 #  define MRN_THD_MAKE_LEX_STRING_USE_CONST_STRING
 #endif
@@ -709,3 +738,28 @@ typedef HASH mrn_table_def_cache_type;
 #else
 #  define mrn_destroy(pointer) delete pointer
 #endif
+
+#if MYSQL_VERSION_ID >= 80013 && !defined(MRN_MARIADB_P)
+#  define mrn_alloc_table_share(table_list, key, key_length) \
+  alloc_table_share((table_list)->db,                        \
+                    (table_list)->table_name,                \
+                    (key),                                   \
+                    (key_length),                            \
+                    false)
+#elif MYSQL_VERSION_ID >= 100306 && defined(MRN_MARIADB_P)
+#  define mrn_alloc_table_share(table_list, key, key_length) \
+  alloc_table_share((table_list)->db.str,                    \
+                    (table_list)->table_name.str,            \
+                    (key),                                   \
+                    (key_length))
+#elif (MYSQL_VERSION_ID >= 100002 && defined(MRN_MARIADB_P)) || \
+  (MYSQL_VERSION_ID >= 80011 && !defined(MRN_MARIADB_P))
+#  define mrn_alloc_table_share(table_list, key, key_length)    \
+  alloc_table_share((table_list)->db,                           \
+                    (table_list)->table_name,                   \
+                    (key),                                      \
+                    (key_length))
+#else
+#  define mrn_alloc_table_share(table_list, key, key_length)    \
+  alloc_table_share((table_list), (key), (key_length))
+#endif
